pymediainfo
-----------
.. image:: https://api.travis-ci.org/sbraz/pymediainfo.svg

This small package is a wrapper around the MediaInfo library. See
https://pymediainfo.readthedocs.io/ for more information.
